==> haskell-hslua-module-system-0.2.2.1-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-system
version:              0.2.2.1
visibility:           public
id:                   hslua-module-system-0.2.2.1-7RINmaSyesmDmNfjJLeGv0
key:                  hslua-module-system-0.2.2.1-7RINmaSyesmDmNfjJLeGv0
license:              MIT
copyright:            © 2019-2020 Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-system
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.

    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.

category:             Foreign
abi:                  5be9e8bd66ec03a007a7d06963a3d4e5
exposed:              True
exposed-modules:      Foreign.Lua.Module.System
hidden-modules:       Foreign.Lua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hslua-module-system-0.2.2.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hslua-module-system-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/hslua-module-system-0.2.2.1

hs-libraries:         HShslua-module-system-0.2.2.1-7RINmaSyesmDmNfjJLeGv0
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    exceptions-0.10.4 hslua-1.3.0.1-9GaXOV1KzZbEclJpYfNxtb
    temporary-1.3-BQuyrd5DWDGHzO3ikF4Vj3

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-0.2.2.1-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-system
version:              0.2.2.1
visibility:           public
id:                   hslua-module-system-0.2.2.1-KuUV9Vp0bLXJksDAIsEx7l
key:                  hslua-module-system-0.2.2.1-KuUV9Vp0bLXJksDAIsEx7l
license:              MIT
copyright:            © 2019-2020 Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-system
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.

    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.

category:             Foreign
abi:                  6b8378208ea51c4fe04b89772bf2eaab
exposed:              True
exposed-modules:      Foreign.Lua.Module.System
hidden-modules:       Foreign.Lua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-8.10.4/site-local/hslua-module-system-0.2.2.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hslua-module-system-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/hslua-module-system-0.2.2.1

hs-libraries:         HShslua-module-system-0.2.2.1-KuUV9Vp0bLXJksDAIsEx7l
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    exceptions-0.10.4 hslua-1.3.0.1-952cB7uWB86CxJkM9RuEbT
    temporary-1.3-LdKCy2uZpQ8IQt0brZbPex

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
